Class: CloudmersiveImageRecognitionApiClient::AiImageDetectionApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cloudmersive-image-recognition-api-client/api/ai_image_detection_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AiImageDetectionApi

Returns a new instance of AiImageDetectionApi.



19
20
21
# File 'lib/cloudmersive-image-recognition-api-client/api/ai_image_detection_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cloudmersive-image-recognition-api-client/api/ai_image_detection_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#ai_image_detection_detect_file(image_file, opts = {}) ⇒ ImageAiDetectionResult

Detect if an input image was generated using AI Detects if the input image was generated using AI tools.

Parameters:

  • image_file

    Image file to perform the operation on. Common file formats such as PNG, JPEG are supported.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/cloudmersive-image-recognition-api-client/api/ai_image_detection_api.rb', line 27

def ai_image_detection_detect_file(image_file, opts = {})
  data, _status_code, _headers = ai_image_detection_detect_file_with_http_info(image_file, opts)
  data
end

#ai_image_detection_detect_file_with_http_info(image_file, opts = {}) ⇒ Array<(ImageAiDetectionResult, Fixnum, Hash)>

Detect if an input image was generated using AI Detects if the input image was generated using AI tools.

Parameters:

  • image_file

    Image file to perform the operation on. Common file formats such as PNG, JPEG are supported.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ImageAiDetectionResult, Fixnum, Hash)>)

    ImageAiDetectionResult data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cloudmersive-image-recognition-api-client/api/ai_image_detection_api.rb', line 37

def ai_image_detection_detect_file_with_http_info(image_file, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AiImageDetectionApi.ai_image_detection_detect_file ...'
  end
  # verify the required parameter 'image_file' is set
  if @api_client.config.client_side_validation && image_file.nil?
    fail ArgumentError, "Missing the required parameter 'image_file' when calling AiImageDetectionApi.ai_image_detection_detect_file"
  end
  # resource path
  local_var_path = '/image/ai-detection/file'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/octet-stream'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data'])

  # form parameters
  form_params = {}
  form_params['imageFile'] = image_file

  # http body (model)
  post_body = nil
  auth_names = ['Apikey']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'ImageAiDetectionResult')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AiImageDetectionApi#ai_image_detection_detect_file\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end